MinimalArchaeology = {}
MinimalArchaeology['skill'] = {}	 -- Store information about the players skill
MinimalArchaeology['artifacts'] = {} -- Store information about current artifacts
MinimalArchaeology['barlinks'] = {1,2,3,4,5,6,7,8,9,10} -- Store information about bar links
MinimalArchaeology['ArtifactBars'] = {} -- References for the artifact bars

SLASH_MINIMALARCHAEOLOGY1 = "/minarch"
SlashCmdList["MINIMALARCHAEOLOGY"] = function(msg, editBox)
    MinimalArchaeologyFrame:Show();
end

function MinimalArchaeology:OnLoad(self)
	-- Register Events
	MinimalArchaeologyFrame:RegisterForDrag("LeftButton")
	
	--MinimalArchaeologyFrame:RegisterEvent("ARTIFACT_UPDATE");
	
	MinimalArchaeologyFrame:RegisterEvent("ARTIFACT_HISTORY_READY");
	MinimalArchaeologyFrame:RegisterEvent("ARTIFACT_COMPLETE");
	MinimalArchaeologyFrame:RegisterEvent("ARTIFACT_DIG_SITE_UPDATED");
	MinimalArchaeologyFrame:RegisterEvent("CURRENCY_DISPLAY_UPDATE");
	MinimalArchaeologyFrame:RegisterEvent("SKILL_LINES_CHANGED");
	MinimalArchaeologyFrame:RegisterEvent("BAG_UPDATE");
	
	for i=1,10 do -- Artifact Arrays
		MinimalArchaeology['artifacts'][i] = {};
	end
	
	-- Set Frames
	MinimalArchaeology['ArtifactBars'][1] = MinimalArchaeologyFrameStatusBar1;
	MinimalArchaeology['ArtifactBars'][2] = MinimalArchaeologyFrameStatusBar2;
	MinimalArchaeology['ArtifactBars'][3] = MinimalArchaeologyFrameStatusBar3;
	MinimalArchaeology['ArtifactBars'][4] = MinimalArchaeologyFrameStatusBar4;
	MinimalArchaeology['ArtifactBars'][5] = MinimalArchaeologyFrameStatusBar5;
	MinimalArchaeology['ArtifactBars'][6] = MinimalArchaeologyFrameStatusBar6;
	MinimalArchaeology['ArtifactBars'][7] = MinimalArchaeologyFrameStatusBar7;
	MinimalArchaeology['ArtifactBars'][8] = MinimalArchaeologyFrameStatusBar8;
	MinimalArchaeology['ArtifactBars'][9] = MinimalArchaeologyFrameStatusBar9;
	MinimalArchaeology['ArtifactBars'][10] = MinimalArchaeologyFrameStatusBar10;
	
	ChatFrame1:AddMessage("Minimal Archaeology Loaded!");
end

function MinimalArchaeology:OnEvent(event, ...)
	MinimalArchaeology:UpdateMinArchRankBar();
end

function MinimalArchaeology:UpdateMinArchSkill()	-- Update archaeology skill information
	local _, _, arch = GetProfessions();
	if arch then
		local name, _, rank, maxRank = GetProfessionInfo(arch);
		MinimalArchaeology['skill']['name'] = name;
		MinimalArchaeology['skill']['rank'] = rank;
		MinimalArchaeology['skill']['maxRank'] = maxRank;
	end
end

function MinimalArchaeology:UpdateMinArchSkillBar(SkillBar)	-- Update a status bar to represent the skill information
	local skill = MinimalArchaeology['skill'];
	
	SkillBar:SetMinMaxValues(0, skill['maxRank']);
	SkillBar:SetValue(skill['rank']);
	SkillBar.text:SetText(skill['name'].." "..skill['rank'].."/"..skill['maxRank']);
end

function MinimalArchaeology:UpdateMinArchArtifact(ArtifactIndex)	-- Update artifact details, only keep relevant data
	local numArtifacts = GetNumArtifactsByRace(ArtifactIndex);
	local RaceName, _, _, RaceitemID = GetArchaeologyRaceInfo(ArtifactIndex);
	
	MinimalArchaeology['artifacts'][ArtifactIndex]['race'] = RaceName;
	
	if (numArtifacts == 0) then	-- The Artifact hasn't been discovered
		MinimalArchaeology['artifacts'][ArtifactIndex]['numKeystones'] = 0;
		MinimalArchaeology['artifacts'][ArtifactIndex]['progress'] = 0;
		MinimalArchaeology['artifacts'][ArtifactIndex]['modifier'] = 0;
		MinimalArchaeology['artifacts'][ArtifactIndex]['total'] = 0;
		MinimalArchaeology['artifacts'][ArtifactIndex]['canSolve'] = false;
	else
		SetSelectedArtifact(ArtifactIndex);
		local Name, Description, Rarity, Icon, SpellDescription, NumKeystones = GetSelectedArtifactInfo();
		local Progress, Modifier, Total = GetArtifactProgress();
		
		MinimalArchaeology['artifacts'][ArtifactIndex]['numKeystones'] = NumKeystones;
		MinimalArchaeology['artifacts'][ArtifactIndex]['progress'] = Progress;
		MinimalArchaeology['artifacts'][ArtifactIndex]['modifier'] = Modifier;
		MinimalArchaeology['artifacts'][ArtifactIndex]['total'] = Total;
		MinimalArchaeology['artifacts'][ArtifactIndex]['canSolve'] = CanSolveArtifact();
	end	
	
	
end

function MinimalArchaeology:UpdateMinArchArtifactBar(ArtifactIndex, ArtifactBar)
	local artifact = MinimalArchaeology['artifacts'][ArtifactIndex];
	local keyStars = "";
	
	ArtifactBar:SetMinMaxValues(0, artifact['total']);
	ArtifactBar:SetValue(min(artifact['progress']+artifact['modifier'], artifact['total']));
		
	if (artifact['numKeystones'] > 0 and artifact['total'] > 0) then
		
		for i=1,artifact['numKeystones'] do
			keyStars = "*"..keyStars;
		end
	end
	
	if (artifact['modifier'] > 0) then
		ArtifactBar.text:SetText(keyStars..artifact['race'].." "..(artifact['progress']+artifact['modifier']).." (+"..artifact['modifier']..")/"..artifact['total']);
	else
		ArtifactBar.text:SetText(keyStars..artifact['race'].." "..artifact['progress'].."/"..artifact['total']);
	end
	
	if (artifact['canSolve']) then
		ArtifactBar.solveButton:Enable();
	else
		ArtifactBar.solveButton:Disable();
	end	
end

function MinimalArchaeology:MinArchSolve(BarIndex)
	SetSelectedArtifact(MinimalArchaeology['barlinks'][BarIndex]);
	SolveArtifact();
end

function MinimalArchaeology:UpdateMinArchRankBar()
	
	MinimalArchaeology:UpdateMinArchSkill();
	MinimalArchaeology:UpdateMinArchSkillBar(MinimalArchaeologyFrameSkillBar);
	
	for i=1,10 do
		MinimalArchaeology:UpdateMinArchArtifact(i);
		MinimalArchaeology:UpdateMinArchArtifactBar(i,MinimalArchaeology['ArtifactBars'][i]);
	end
end